pub fn calc_graph<'a>(
commits: &'a [VoidCommit],
ctx: &'a impl GraphContext,
) -> Graph<'a>Expand description
Calculate the graph layout for a list of commits.
pub fn calc_graph<'a>(
commits: &'a [VoidCommit],
ctx: &'a impl GraphContext,
) -> Graph<'a>Calculate the graph layout for a list of commits.