Terminal image protocol encoding.
This module provides support for displaying images in terminals using the iTerm2 and Kitty graphics protocols.
Adapted from Serie by lusingander, licensed under MIT.
Enums
- Image
Protocol - Supported terminal image protocols.
Functions
- auto_
detect - Auto-detect the best image protocol for the current terminal.