pub struct RefListState { /* private fields */ }Expand description
State for the ref list widget.
Implementations
Sourceimpl RefListState
impl RefListState
Sourcepub fn selected_ref_name(&self) -> Option<&str>
pub fn selected_ref_name(&self) -> Option<&str>
Get the currently selected ref name, if a leaf is selected.
Sourcepub fn selected_ref(&self) -> Option<&VoidRef>
pub fn selected_ref(&self) -> Option<&VoidRef>
Get the selected ref if a leaf is selected.
Sourcepub fn select_next(&mut self, viewport_height: usize)
pub fn select_next(&mut self, viewport_height: usize)
Move selection down.
Sourcepub fn select_prev(&mut self)
pub fn select_prev(&mut self)
Move selection up.
Sourcepub fn toggle_selected(&mut self)
pub fn toggle_selected(&mut self)
Toggle expansion of selected category.
Sourcepub fn select_first(&mut self)
pub fn select_first(&mut self)
Jump to first node.
Sourcepub fn select_last(&mut self, viewport_height: usize)
pub fn select_last(&mut self, viewport_height: usize)
Jump to last node.