pub fn auto_detect() -> ImageProtocolExpand description
Auto-detect the best image protocol for the current terminal.
By default assumes iTerm2 is the best protocol to use for all terminals unless an environment variable is set that suggests the terminal is probably Kitty.